# Tutorials

The step-by-step guides, the how-to's, the recipes, and all the Aio Fluid parts you can use in your back-end applications.

Each section gradually builds on the previous ones, but it's structured to separate topics, so that you can go directly to any specific one to solve your specific needs.


## Install Aio Fluid

To install Aio Fluid, you can use the following command:

```bash
pip install aio-fluid
```

if you want to use the async database module, you can install it with the following command:

```bash
pip install aio-fluid[db]
```

if you want to use the command line interface (highly recommended), you can install it with the following command:

```bash
pip install aio-fluid[cli]
```
